pub fn purge_keys_from_ah<T: Config>(stash: T::AccountId)Expand description
Purge session keys for a validator, forwarded from AssetHub.
This is called when a validator purges their session keys on AssetHub, which forwards the request to the RelayChain via XCM.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::purge_keys_from_ah.