referrerpolicy=no-referrer-when-downgrade

set_keys_from_ah

Function set_keys_from_ah 

pub fn set_keys_from_ah<T: Config>(stash: T::AccountId, keys: Vec<u8>)
Set session keys for a validator, forwarded from AssetHub.

This is called when a validator sets their session keys on AssetHub, which forwards the request to the RelayChain via XCM.

AssetHub validates both keys and ownership proof before sending. RC trusts AH’s validation and does not re-validate.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::set_keys_from_ah.